@@ -1,7 +1,7 @@
 modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1,
                        gamdisp = NULL, second.ord = TRUE, nobs = NULL, uncond.se = "revised", parm.type = NULL){
   results <- NULL
-  known <- rep(0, 5) #create an identifier of class type for lm, glm, lme, mer, unmarked,
+  known <- rep(0, 6) #create an identifier of class type for lm, glm, lme, mer, unmarked,
   ##extract classes
   mod.class <- unlist(lapply(X = cand.set, FUN = class))
   ##check if all are identical
@@ -47,6 +47,13 @@ modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1
     known[5] <- 1
   }
 
+  ##determine if rlm
+  if(identical(check.class, c("rlm", "lm")))  {
+    results <- modavgpred.rlm(cand.set = cand.set, modnames = modnames, newdata = newdata,
+                              second.ord = second.ord, nobs = nobs, uncond.se = uncond.se)
+    known[6] <- 1
+  }
+
     
   ##warn if class is neither lm, glm, lme, unmarked, nor coxph
   if(sum(known) < 1) {stop("\nFunction not yet defined for this object class")}
@@ -131,12 +138,12 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
       for (obs in 1:nobserv) {
 
         ##extract fitted value for observation obs
-        fit <- unlist(lapply(X = cand.set, FUN = function(i)predict(i, se.fit = TRUE, newdata = newdata[obs, ],
-                                         type = type, dispersion = dispersion)$fit))
+        fit <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                             type = type, dispersion = dispersion)$fit))
 
         ##extract SE for fitted value for observation obs
-        SE <- unlist(lapply(X = cand.set, FUN = function(i)predict(i, se.fit = TRUE, newdata = newdata[obs, ],
-                                        type = type, dispersion = dispersion)$se.fit))
+        SE <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                            type = type, dispersion = dispersion)$se.fit))
 
 
         ##create temporary data.frame to store fitted values and SE 
@@ -150,12 +157,12 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
 
         ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
         if(identical(uncond.se, "old")) {
-          Mod.avg.out[obs, 2] <- sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2))
+          Mod.avg.out[obs, 2] <- sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2))
         }
 
         ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
         if(identical(uncond.se, "revised")) {
-          Mod.avg.out[obs, 2] <- sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2)))
+          Mod.avg.out[obs, 2] <- sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2)))
         }
       }
     }
@@ -168,11 +175,11 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
       for (obs in 1:nobserv) {
 
         ##extract fitted value for observation obs
-        fit <- unlist(lapply(X = cand.set, FUN=function(i)predict(i, se.fit = TRUE, newdata = newdata[obs, ],
-                                         type = type, dispersion = dispersion)$fit))
+        fit <- unlist(lapply(X = cand.set, FUN=function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                             type = type, dispersion = dispersion)$fit))
         ##extract SE for fitted value for observation obs
-        SE <- unlist(lapply(X = cand.set, FUN = function(i)predict(i, se.fit = TRUE, newdata = newdata[obs, ],
-                                        type = type, dispersion = dispersion)$se.fit))
+        SE <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                            type = type, dispersion = dispersion)$se.fit))
 
         QAICctmp <- AICctab
         QAICctmp$fit <- fit
@@ -184,12 +191,12 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
         ##compute unconditional SE and store in output matrix
         ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
         if(identical(uncond.se, "old")) {
-          Mod.avg.out[obs, 2] <- sum(QAICctmp$QAICcWt*sqrt(QAICctmp$SE^2 + (QAICctmp$fit- Mod.avg.out[obs, 1])^2))
+          Mod.avg.out[obs, 2] <- sum(QAICctmp$QAICcWt*sqrt(QAICctmp$SE^2 + (QAICctmp$fit - Mod.avg.out[obs, 1])^2))
         }
 
         ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
         if(identical(uncond.se, "revised")) {
-          Mod.avg.out[obs, 2] <- sqrt(sum(QAICctmp$QAICcWt*(QAICctmp$SE^2 + (QAICctmp$fit- Mod.avg.out[obs, 1])^2)))  
+          Mod.avg.out[obs, 2] <- sqrt(sum(QAICctmp$QAICcWt*(QAICctmp$SE^2 + (QAICctmp$fit - Mod.avg.out[obs, 1])^2)))  
         }
       }
     }
@@ -202,11 +209,11 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
       for (obs in 1:nobserv) {
 
         ##extract fitted value for observation obs
-        fit <- unlist(lapply(X = cand.set, FUN = function(i)predict(i, se.fit = TRUE, newdata = newdata[obs, ],
-                                         type = type, dispersion = dispersion)$fit))
+        fit <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                             type = type, dispersion = dispersion)$fit))
         ##extract SE for fitted value for observation obs
-        SE <- unlist(lapply(X = cand.set, FUN = function(i)predict(i, se.fit = TRUE, newdata = newdata[obs, ], type = type,
-                                        dispersion = dispersion)$se.fit))
+        SE <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ], type = type,
+                                            dispersion = dispersion)$se.fit))
 
         AICtmp <- AICctab
         AICtmp$fit <- fit
@@ -218,12 +225,12 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
         ##compute unconditional SE and store in output matrix
         ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
         if(identical(uncond.se, "old")) {
-          Mod.avg.out[obs, 2] <- sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2))
+          Mod.avg.out[obs, 2] <- sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2))
         }
 
         ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
         if(identical(uncond.se, "revised")) {
-          Mod.avg.out[obs, 2] <- sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2)))
+          Mod.avg.out[obs, 2] <- sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2)))
         }  
         
       }
@@ -237,10 +244,10 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
       for (obs in 1:nobserv) {
 
         ##extract fitted value for observation obs
-        fit <- unlist(lapply(X = cand.set, FUN = function(i)predict(i, se.fit = TRUE, newdata = newdata[obs, ],
+        fit <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ],
                                          type = type, dispersion = dispersion)$fit))
         ##extract SE for fitted value for observation obs
-        SE <- unlist(lapply(X = cand.set, FUN = function(i)predict(i, se.fit = TRUE, newdata = newdata[obs, ],
+        SE <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ],
                                         type = type, dispersion = dispersion)$se.fit))
 
         QAICtmp <- AICctab
@@ -283,7 +290,7 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
 
   ##check if object is of "lm" or "glm" class
   ##extract classes
-  mod.class <- unlist(lapply(X=cand.set, FUN=class))
+  mod.class <- unlist(lapply(X = cand.set, FUN = class))
   ##check if all are identical
   check.class <- unique(mod.class)
 
@@ -299,11 +306,11 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
     if(ncolumns == 1) newdata$blank.fake.column.NAs <- NA
  
     ##store AICc table
-    AICctab<-aictab(cand.set=cand.set, modnames=modnames, second.ord=second.ord, nobs=nobs, sort=FALSE)
+    AICctab <- aictab(cand.set = cand.set, modnames = modnames, second.ord = second.ord, nobs = nobs, sort = FALSE)
 
     ##create object to hold Model-averaged estimates and unconditional SE's
-    Mod.avg.out<-matrix(NA, nrow=nobserv, ncol=2)
-    colnames(Mod.avg.out)<-c("Mod.avg.est", "Uncond.SE")
+    Mod.avg.out <- matrix(NA, nrow = nobserv, ncol = 2)
+    colnames(Mod.avg.out) <- c("Mod.avg.est", "Uncond.SE")
 
 
 
@@ -313,29 +320,29 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
       for (obs in 1:nobserv) {
 
         ##extract fitted value for observation obs
-        fit<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.lme(i, se.fit=TRUE, newdata=newdata[obs, ])$fit))
+        fit <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.lme(i, se.fit = TRUE, newdata = newdata[obs, ])$fit))
 
         ##extract SE for fitted value for observation obs
-        SE<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.lme(i, se.fit=TRUE, newdata=newdata[obs, ])$se.fit))
+        SE <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.lme(i, se.fit = TRUE, newdata = newdata[obs, ])$se.fit))
 
 
         ##create temporary data.frame to store fitted values and SE 
-        AICctmp<-AICctab
-        AICctmp$fit<-fit
-        AICctmp$SE<-SE
+        AICctmp <- AICctab
+        AICctmp$fit <- fit
+        AICctmp$SE <- SE
 
         ##compute model averaged prediction and store in output matrix
-        Mod.avg.out[obs, 1]<-sum(AICctmp$AICcWt*AICctmp$fit)
+        Mod.avg.out[obs, 1] <- sum(AICctmp$AICcWt*AICctmp$fit)
         ##compute unconditional SE and store in output matrix
 
         ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
         if(identical(uncond.se, "old")) {
-          Mod.avg.out[obs, 2]<-sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2))
+          Mod.avg.out[obs, 2] <- sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2))
         }
 
         ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
         if(identical(uncond.se, "revised")) {
-          Mod.avg.out[obs, 2]<-sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2)))
+          Mod.avg.out[obs, 2] <- sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2)))
         }
       }
     }
@@ -343,30 +350,30 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
 
 
     ##create temporary data.frame to store fitted values and SE - AIC
-    if(second.ord==FALSE) {
+    if(second.ord == FALSE) {
       for (obs in 1:nobserv) {
 
         ##extract fitted value for observation obs
-        fit<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.lme(i, se.fit=TRUE, newdata=newdata[obs, ])$fit))
+        fit <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.lme(i, se.fit = TRUE, newdata = newdata[obs, ])$fit))
         ##extract SE for fitted value for observation obs
-        SE<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.lme(i, se.fit=TRUE, newdata=newdata[obs, ])$se.fit))
+        SE <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.lme(i, se.fit = TRUE, newdata = newdata[obs, ])$se.fit))
 
-        AICtmp<-AICctab
-        AICtmp$fit<-fit
-        AICtmp$SE<-SE
+        AICtmp <- AICctab
+        AICtmp$fit <- fit
+        AICtmp$SE <- SE
 
         ##compute model averaged prediction and store in output matrix
-        Mod.avg.out[obs, 1]<-sum(AICtmp$AICWt*AICtmp$fit)
+        Mod.avg.out[obs, 1] <- sum(AICtmp$AICWt*AICtmp$fit)
 
         ##compute unconditional SE and store in output matrix
         ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
         if(identical(uncond.se, "old")) {
-          Mod.avg.out[obs, 2]<-sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2))
+          Mod.avg.out[obs, 2] <- sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2))
         }
 
         ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
         if(identical(uncond.se, "revised")) {
-          Mod.avg.out[obs, 2]<-sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2)))
+          Mod.avg.out[obs, 2] <- sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2)))
         }  
         
       }
@@ -418,40 +425,40 @@ modavgpred.mer <- function(cand.set, modnames, newdata, type = "response", c.hat
   AICctab<-aictab(cand.set=cand.set, modnames=modnames, second.ord=second.ord, nobs=nobs, sort=FALSE)
 
   ##create object to hold Model-averaged estimates and unconditional SE's
-  Mod.avg.out<-matrix(NA, nrow=nobserv, ncol=2)
-  colnames(Mod.avg.out)<-c("Mod.avg.est", "Uncond.SE")
+  Mod.avg.out <- matrix(NA, nrow = nobserv, ncol = 2)
+  colnames(Mod.avg.out) <- c("Mod.avg.est", "Uncond.SE")
 
 
   ##begin loop - AICc
-  if(second.ord==TRUE && c.hat==1){
+  if(second.ord == TRUE && c.hat == 1){
     for (obs in 1:nobserv) {
 
       ##extract fitted value for observation obs
-      fit<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.mer(i, se.fit=TRUE, newdata=newdata[obs, ],
-                                       type=type, level = 0)$fit))
+      fit <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.mer(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                       type = type, level = 0)$fit))
 
       ##extract SE for fitted value for observation obs
-      SE<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.mer(i, se.fit=TRUE, newdata=newdata[obs, ],
-                                      type=type, level = 0)$se.fit))
+      SE <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.mer(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                      type = type, level = 0)$se.fit))
 
 
       ##create temporary data.frame to store fitted values and SE 
-      AICctmp<-AICctab
-      AICctmp$fit<-fit
-      AICctmp$SE<-SE
+      AICctmp <- AICctab
+      AICctmp$fit <- fit
+      AICctmp$SE <- SE
 
       ##compute model averaged prediction and store in output matrix
-      Mod.avg.out[obs, 1]<-sum(AICctmp$AICcWt*AICctmp$fit)
+      Mod.avg.out[obs, 1] <- sum(AICctmp$AICcWt*AICctmp$fit)
       ##compute unconditional SE and store in output matrix
 
       ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
       if(identical(uncond.se, "old")) {
-        Mod.avg.out[obs, 2]<-sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2))
+        Mod.avg.out[obs, 2] <- sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2))
       }
 
       ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
       if(identical(uncond.se, "revised")) {
-        Mod.avg.out[obs, 2]<-sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2)))
+        Mod.avg.out[obs, 2] <- sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2)))
       }
     }
   }
@@ -460,32 +467,32 @@ modavgpred.mer <- function(cand.set, modnames, newdata, type = "response", c.hat
 
 
   ##create temporary data.frame to store fitted values and SE - AIC
-  if(second.ord==FALSE && c.hat==1) {
+  if(second.ord == FALSE && c.hat == 1) {
     for (obs in 1:nobserv) {
       
       ##extract fitted value for observation obs
-      fit<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.mer(i, se.fit=TRUE, newdata=newdata[obs, ],
-                                       type=type, level = 0)$fit))
+      fit <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.mer(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                       type = type, level = 0)$fit))
       ##extract SE for fitted value for observation obs
-      SE<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.mer(i, se.fit=TRUE, newdata=newdata[obs, ],
-                                      type=type, level = 0)$se.fit))
+      SE <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.mer(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                      type = type, level = 0)$se.fit))
 
-      AICtmp<-AICctab
-      AICtmp$fit<-fit
-      AICtmp$SE<-SE
+      AICtmp <- AICctab
+      AICtmp$fit <- fit
+      AICtmp$SE <- SE
 
       ##compute model averaged prediction and store in output matrix
-      Mod.avg.out[obs, 1]<-sum(AICtmp$AICWt*AICtmp$fit)
+      Mod.avg.out[obs, 1] <- sum(AICtmp$AICWt*AICtmp$fit)
 
       ##compute unconditional SE and store in output matrix
       ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
       if(identical(uncond.se, "old")) {
-        Mod.avg.out[obs, 2]<-sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2))
+        Mod.avg.out[obs, 2] <- sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2))
       }
 
       ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
       if(identical(uncond.se, "revised")) {
-        Mod.avg.out[obs, 2]<-sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2)))
+        Mod.avg.out[obs, 2] <- sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2)))
       }  
     }
   }
@@ -524,11 +531,11 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
     if(ncolumns == 1) newdata$blank.fake.column.NAs <- NA
  
     ##store AICc table
-    AICctab<-aictab(cand.set=cand.set, modnames=modnames, second.ord=second.ord, nobs=nobs, sort=FALSE)
+    AICctab <- aictab(cand.set = cand.set, modnames = modnames, second.ord = second.ord, nobs = nobs, sort = FALSE)
 
     ##create object to hold Model-averaged estimates and unconditional SE's
-    Mod.avg.out<-matrix(NA, nrow=nobserv, ncol=2)
-    colnames(Mod.avg.out)<-c("Mod.avg.est", "Uncond.SE")
+    Mod.avg.out <- matrix(NA, nrow = nobserv, ncol = 2)
+    colnames(Mod.avg.out) <- c("Mod.avg.est", "Uncond.SE")
 
 
 
@@ -538,29 +545,29 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
       for (obs in 1:nobserv) {
 
         ##extract fitted value for observation obs
-        fit<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.gls(i, se.fit=TRUE, newdata=newdata[obs, ])$fit))
+        fit <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.gls(i, se.fit = TRUE, newdata = newdata[obs, ])$fit))
 
         ##extract SE for fitted value for observation obs
-        SE<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.gls(i, se.fit=TRUE, newdata=newdata[obs, ])$se.fit))
+        SE <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.gls(i, se.fit = TRUE, newdata = newdata[obs, ])$se.fit))
 
 
         ##create temporary data.frame to store fitted values and SE 
-        AICctmp<-AICctab
-        AICctmp$fit<-fit
-        AICctmp$SE<-SE
+        AICctmp <- AICctab
+        AICctmp$fit <- fit
+        AICctmp$SE <- SE
 
         ##compute model averaged prediction and store in output matrix
-        Mod.avg.out[obs, 1]<-sum(AICctmp$AICcWt*AICctmp$fit)
+        Mod.avg.out[obs, 1] <- sum(AICctmp$AICcWt*AICctmp$fit)
         ##compute unconditional SE and store in output matrix
 
         ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
         if(identical(uncond.se, "old")) {
-          Mod.avg.out[obs, 2]<-sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2))
+          Mod.avg.out[obs, 2] <- sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2))
         }
 
         ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
         if(identical(uncond.se, "revised")) {
-          Mod.avg.out[obs, 2]<-sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2)))
+          Mod.avg.out[obs, 2] <- sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2)))
         }
       }
     }
@@ -568,30 +575,30 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
 
 
     ##create temporary data.frame to store fitted values and SE - AIC
-    if(second.ord==FALSE) {
+    if(second.ord == FALSE) {
       for (obs in 1:nobserv) {
 
         ##extract fitted value for observation obs
-        fit<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.gls(i, se.fit=TRUE, newdata=newdata[obs, ])$fit))
+        fit <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.gls(i, se.fit = TRUE, newdata = newdata[obs, ])$fit))
         ##extract SE for fitted value for observation obs
-        SE<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.gls(i, se.fit=TRUE, newdata=newdata[obs, ])$se.fit))
+        SE <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.gls(i, se.fit = TRUE, newdata = newdata[obs, ])$se.fit))
 
-        AICtmp<-AICctab
-        AICtmp$fit<-fit
-        AICtmp$SE<-SE
+        AICtmp <- AICctab
+        AICtmp$fit <- fit
+        AICtmp$SE <- SE
 
         ##compute model averaged prediction and store in output matrix
-        Mod.avg.out[obs, 1]<-sum(AICtmp$AICWt*AICtmp$fit)
+        Mod.avg.out[obs, 1] <- sum(AICtmp$AICWt*AICtmp$fit)
 
         ##compute unconditional SE and store in output matrix
         ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
         if(identical(uncond.se, "old")) {
-          Mod.avg.out[obs, 2]<-sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2))
+          Mod.avg.out[obs, 2] <- sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2))
         }
 
         ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
         if(identical(uncond.se, "revised")) {
-          Mod.avg.out[obs, 2]<-sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2)))
+          Mod.avg.out[obs, 2] <- sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2)))
         }  
         
       }
@@ -611,6 +618,111 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
 
 
 
+modavgpred.rlm <-
+  function(cand.set, modnames, newdata, second.ord = TRUE, nobs = NULL, uncond.se = "revised") {
+  ##newdata is data frame with exact structure of the original data frame (same variable names and type)
+
+  ##check if object is of "rlm" class
+  ##extract classes
+  mod.class <- unlist(lapply(X = cand.set, FUN = class))
+  ##check if all are identical
+  check.class <- unique(mod.class)
+
+  if(identical(check.class, c("rlm", "lm")))  {
+
+    ##determine number of observations in new data set
+    nobserv <- dim(newdata)[1]
+
+    ##determine number of columns in new data set
+    ncolumns <- dim(newdata)[2]
+
+    ##if only 1 column, add an additional column to avoid problems in computation with predictSE.mer( )
+    if(ncolumns == 1) newdata$blank.fake.column.NAs <- NA
+ 
+    ##store AICc table
+    AICctab <- aictab(cand.set = cand.set, modnames = modnames, second.ord = second.ord,
+                      nobs = nobs, sort = FALSE)
+
+    ##create object to hold Model-averaged estimates and unconditional SE's
+    Mod.avg.out <- matrix(NA, nrow = nobserv, ncol = 2)
+    colnames(Mod.avg.out) <- c("Mod.avg.est", "Uncond.SE")
+
+
+    ##begin loop - AICc
+    if(second.ord == TRUE){
+      for (obs in 1:nobserv) {
+
+        ##extract fitted value for observation obs
+        fit <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ])$fit))
+
+        ##extract SE for fitted value for observation obs
+        SE <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ])$se.fit))
+
+
+        ##create temporary data.frame to store fitted values and SE 
+        AICctmp <- AICctab
+        AICctmp$fit <- fit
+        AICctmp$SE <- SE
+
+        ##compute model averaged prediction and store in output matrix
+        Mod.avg.out[obs, 1] <- sum(AICctmp$AICcWt*AICctmp$fit)
+        ##compute unconditional SE and store in output matrix
+
+        ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
+        if(identical(uncond.se, "old")) {
+          Mod.avg.out[obs, 2] <- sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2))
+        }
+
+        ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
+        if(identical(uncond.se, "revised")) {
+          Mod.avg.out[obs, 2] <- sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2)))
+        }
+      }
+    }
+
+
+
+    ##create temporary data.frame to store fitted values and SE - AIC
+    if(second.ord == FALSE) {
+      for (obs in 1:nobserv) {
+
+        ##extract fitted value for observation obs
+        fit <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ])$fit))
+        ##extract SE for fitted value for observation obs
+        SE <- unlist(lapply(X = cand.set, FUN = function(i) predict(i, se.fit = TRUE, newdata = newdata[obs, ])$se.fit))
+
+        AICtmp <- AICctab
+        AICtmp$fit <- fit
+        AICtmp$SE <- SE
+
+        ##compute model averaged prediction and store in output matrix
+        Mod.avg.out[obs, 1] <- sum(AICtmp$AICWt*AICtmp$fit)
+
+        ##compute unconditional SE and store in output matrix
+        ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
+        if(identical(uncond.se, "old")) {
+          Mod.avg.out[obs, 2] <- sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2))
+        }
+
+        ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
+        if(identical(uncond.se, "revised")) {
+          Mod.avg.out[obs, 2] <- sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2)))
+        }  
+        
+      }
+    }
+
+
+
+    Mod.pred.list <- list("mod.avg.pred" = Mod.avg.out[,1], "uncond.se" = Mod.avg.out[,2])
+    class(Mod.pred.list) <- c("modavgpred", "list")
+    return(Mod.pred.list)
+    
+  } else {stop("\nThis function is only appropriate with \'rlm\' class\n")}
+}
+
+
+
 
 
 
